@@ -155,7 +155,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.2.710");
+    setStatus("Using qgvdial version 0.2.715");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -357,15 +357,7 @@ MainWindow::init ()
     logLevel = dbMain.getLogLevel ();
 
     // Pick up proxy settings from the DB and apply to webpage.
-    bool bProxyEnable = false, bUseSystemProxy = false;
-    bool bProxyAuthRequired = false;
-    QString strProxyHost, strProxyUser, strProxyPass;
-    int proxy_port = 0;
-    dbMain.getProxySettings (bProxyEnable, bUseSystemProxy,
-                             strProxyHost, proxy_port,
-                             bProxyAuthRequired, strProxyUser, strProxyPass);
-    onSigProxyChanges (bProxyEnable, bUseSystemProxy, strProxyHost, proxy_port,
-                       bProxyAuthRequired, strProxyUser, strProxyPass);
+    onSigProxyRefresh (true);
 
     // Initialize the DBUS interface to allow other applications (and qgv-tp) to
     // initiate calls and send texts through us.
@@ -567,6 +559,7 @@ MainWindow::initQML ()
 
     // Initialize the QML view
     this->setSource (QUrl ("qrc:/Main.qml"));
+    this->setResizeMode (QDeclarativeView::SizeRootObjectToView);
 
     this->setUsername ("example@gmail.com");
     this->setPassword ("hunter2 :p");
@@ -619,6 +612,12 @@ MainWindow::initQML ()
     bOk = connect (gObj, SIGNAL (sigRefreshAll ()),
                    this, SLOT   (onRefreshAll ()));
     Q_ASSERT(bOk);
+    bOk = connect (gObj, SIGNAL (sigRefreshInbox ()),
+                   this, SLOT   (onSigRefreshInbox ()));
+    Q_ASSERT(bOk);
+    bOk = connect (gObj, SIGNAL (sigRefreshContacts ()),
+                   this, SLOT   (onSigRefreshContacts ()));
+    Q_ASSERT(bOk);
     bOk = connect (gObj, SIGNAL (sigHide ()),
                    this, SLOT   (onSigHide ()));
     Q_ASSERT(bOk);
@@ -633,6 +632,8 @@ MainWindow::initQML ()
                                       bool, const QString &, const QString &)),
         this, SLOT (onSigProxyChanges(bool, bool, const QString &, int,
                                       bool, const QString &, const QString &)));
+    bOk = connect (gObj, SIGNAL (sigProxyRefresh()),
+                   this, SLOT (onSigProxyRefresh()));
     Q_ASSERT(bOk);
     bOk = connect (
         gObj, SIGNAL (sigMosquittoChanges(bool, const QString &, int,
@@ -640,10 +641,16 @@ MainWindow::initQML ()
         this, SLOT   (onSigMosquittoChanges(bool, const QString &, int,
                                             const QString &)));
     Q_ASSERT(bOk);
+    bOk = connect (gObj, SIGNAL (sigMosquittoRefresh()),
+                   this, SLOT   (refreshMqSettings()));
+    Q_ASSERT(bOk);
     bOk = connect (
         gObj, SIGNAL(sigPinSettingChanges  (bool, const QString &)),
         this, SLOT  (onSigPinSettingChanges(bool, const QString &)));
     Q_ASSERT(bOk);
+    bOk = connect (gObj, SIGNAL(sigPinRefresh()),
+                   this, SLOT  (refreshPinSettings()));
+    Q_ASSERT(bOk);
     bOk = connect (gObj, SIGNAL (sigMsgBoxDone(bool)),
                    this, SLOT (onSigMsgBoxDone(bool)));
     Q_ASSERT(bOk);
@@ -768,8 +775,7 @@ MainWindow::loginCompleted (bool bOk, const QVariantList & /*varList*/)
     strSelfNumber.clear ();
     webPage.setTimeout(20);
 
-    if (!bOk)
-    {
+    if (!bOk) {
         QVariantList l;
         logoutCompleted (true, l);
 
@@ -818,16 +824,11 @@ MainWindow::loginCompleted (bool bOk, const QVariantList & /*varList*/)
         // Fill up the combobox on the main page
         refreshRegisteredNumbers ();
 
-        bool bMqEnabled;
-        QString strMqHost, strMqTopic;
-        int mqPort;
-        if (dbMain.getMqSettings (bMqEnabled, strMqHost, mqPort, strMqTopic)) {
-            onSigMosquittoChanges (bMqEnabled, strMqHost, mqPort, strMqTopic);
-        }
+        // Fill up the mq settings
+        refreshMqSettings ();
 
-        if (dbMain.getGvPin (bMqEnabled, strMqHost)) {
-            onSigPinSettingChanges (bMqEnabled, strMqHost);
-        }
+        // Fill up the pin settings
+        refreshPinSettings ();
     }
 }//MainWindow::loginCompleted
 
@@ -1048,8 +1049,7 @@ MainWindow::dialNow (const QString &strTarget)
 {
     CalloutInitiator *ci;
 
-    do // Begin cleanup block (not a loop)
-    {
+    do { // Begin cleanup block (not a loop)
         if (!bLoggedIn) {
             setStatus ("User is not logged in yet. Cannot make any calls.");
             break;
@@ -1068,8 +1068,7 @@ MainWindow::dialNow (const QString &strTarget)
         }
 
         GVRegisteredNumber gvRegNumber;
-        if (!getDialSettings (bDialout, gvRegNumber, ci))
-        {
+        if (!getDialSettings (bDialout, gvRegNumber, ci)) {
             setStatus ("Unable to dial because settings are not valid.");
             break;
         }
@@ -1623,6 +1622,22 @@ MainWindow::onRefreshAll ()
     oContacts.refreshAllContacts ();
 }//MainWindow::onRefreshAll
 
+void
+MainWindow::onSigRefreshContacts()
+{
+    qDebug ("Refresh Contacts requested.");
+
+    oContacts.refreshContacts ();
+}//MainWindow::onSigRefreshContacts
+
+void
+MainWindow::onSigRefreshInbox()
+{
+    qDebug ("Refresh inbox requested.");
+
+    oInbox.refresh ();
+}//MainWindow::onSigRefreshInbox
+
 void
 MainWindow::onSigProxyChanges(bool bEnable, bool bUseSystemProxy,
                               const QString &host, int port, bool bRequiresAuth,
@@ -1636,9 +1651,25 @@ MainWindow::onSigProxyChanges(bool bEnable, bool bUseSystemProxy,
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     dbMain.setProxySettings (bEnable, bUseSystemProxy, host, port,
                              bRequiresAuth, user, pass);
+}//MainWindow::onSigProxyChanges
 
-    do // Begin cleanup block (not a loop)
-    {
+void
+MainWindow::onSigProxyRefresh(bool bSet)
+{
+    bool bEnable, bUseSystemProxy, bRequiresAuth;
+    int port;
+    QString host, user, pass;
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain();
+
+    dbMain.getProxySettings (bEnable, bUseSystemProxy, host, port,
+                             bRequiresAuth, user, pass);
+
+    if (bSet) {
+        onSigProxyChanges (bEnable, bUseSystemProxy, host, port,
+                           bRequiresAuth, user, pass);
+    }
+
+    do { // Begin cleanup block (not a loop)
         QObject *pRoot = this->rootObject ();
         if (NULL == pRoot) {
             qWarning ("Couldn't get root object in QML for ProxySettingsPage");
@@ -1646,7 +1677,7 @@ MainWindow::onSigProxyChanges(bool bEnable, bool bUseSystemProxy,
         }
 
         QObject *pProxySettings = pRoot->findChild <QObject*>
-                                                  ("ProxySettingsPage");
+                ("ProxySettingsPage");
         if (NULL == pProxySettings) {
             qWarning ("Could not get to ProxySettingsPage");
             break;
@@ -1661,7 +1692,7 @@ MainWindow::onSigProxyChanges(bool bEnable, bool bUseSystemProxy,
                                    Q_ARG (QVariant, QVariant(user)),
                                    Q_ARG (QVariant, QVariant(pass)));
     } while (0); // End cleanup block (not a loop)
-}//MainWindow::onSigProxyChanges
+}//MainWindow::onSigProxyRefresh
 
 void
 MainWindow::onLinkActivated (const QString &strLink)
@@ -1677,8 +1708,6 @@ MainWindow::onSigMosquittoChanges (bool bEnable, const QString &host, int port,
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     dbMain.setMqSettings (bEnable, host, port, topic);
 
-    setMqSettingsInQml (bEnable, host, port, topic);
-
 #if MOSQUITTO_CAPABLE
     mqThread.setSettings (bEnable, host, port);
     bRunMqThread = bEnable;
@@ -1691,19 +1720,27 @@ MainWindow::onSigMosquittoChanges (bool bEnable, const QString &host, int port,
 }//MainWindow::onSigMosquittoChanges
 
 void
-MainWindow::setMqSettingsInQml (bool bEnable, const QString &host, int port,
-                                const QString &topic)
+MainWindow::refreshMqSettings (bool bForceShut /*= false*/)
 {
-    do // Begin cleanup block (not a loop)
-    {
+    bool bEnable = bForceShut;
+    QString host, topic;
+    int port;
+
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    if (!bForceShut) {
+        if (!dbMain.getMqSettings (bEnable, host, port, topic)) {
+            return;
+        }
+    }
+
+    do { // Begin cleanup block (not a loop)
         QObject *pRoot = this->rootObject ();
         if (NULL == pRoot) {
             qWarning ("Couldn't get root object in QML for MosquittoPage");
             break;
         }
 
-        QObject *pMqSettings = pRoot->findChild <QObject*>
-                                                  ("MosquittoPage");
+        QObject *pMqSettings = pRoot->findChild <QObject*> ("MosquittoPage");
         if (NULL == pMqSettings) {
             qWarning ("Could not get to MosquittoPage");
             break;
@@ -1729,7 +1766,7 @@ MainWindow::setMqSettingsInQml (bool bEnable, const QString &host, int port,
                                    Q_ARG (QVariant, QVariant(port)),
                                    Q_ARG (QVariant, QVariant(strTopic)));
     } while (0); // End cleanup block (not a loop)
-}//MainWindow::setMqSettingsInQml
+}//MainWindow::refreshMqSettings
 
 void
 MainWindow::onSigPinSettingChanges(bool bEnable, const QString &pin)
@@ -1738,17 +1775,29 @@ MainWindow::onSigPinSettingChanges(bool bEnable, const QString &pin)
 
     CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
     dbMain.setGvPin (bEnable, strPin);
+}//MainWindow::onSigPinSettingChanges
+
+void
+MainWindow::refreshPinSettings()
+{
+    bool bEnable;
+    QString strPin;
+
+    CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
+    if (!dbMain.getGvPin (bEnable, strPin)) {
+        return;
+    }
+
     if (bEnable) {
         strGvPin = strPin;
     } else {
-        strGvPin.clear ();
+        strGvPin = "0000";
     }
 
-    do // Begin cleanup block (not a loop)
-    {
+    do { // Begin cleanup block (not a loop)
         QObject *pRoot = this->rootObject ();
         if (NULL == pRoot) {
-            qWarning ("Couldn't get root object in QML for MosquittoPage");
+            qWarning ("Couldn't get root object in QML for PinSettingsPage");
             break;
         }
 
@@ -1762,7 +1811,7 @@ MainWindow::onSigPinSettingChanges(bool bEnable, const QString &pin)
                                    Q_ARG (QVariant, QVariant(bEnable)),
                                    Q_ARG (QVariant, QVariant(strPin)));
     } while (0); // End cleanup block (not a loop)
-}//MainWindow::onSigPinSettingChanges
+}//MainWindow::refreshPinSettings
 
 void
 MainWindow::onMqThreadFinished ()
@@ -1776,13 +1825,7 @@ MainWindow::onMqThreadFinished ()
         qDebug ("Finished waiting for Mq thread. Not restarting");
 
         // Just send a command to turn off mosquitto enable
-        CacheDatabase &dbMain = Singletons::getRef().getDBMain ();
-        bool bEnable;
-        QString host, topic;
-        int port;
-        dbMain.getMqSettings (bEnable, host, port, topic);
-        bEnable = false;
-        setMqSettingsInQml (bEnable, host, port, topic);
+        refreshMqSettings (true);
     }
 #endif
 }//MainWindow::onMqThreadFinished
